package Petal::Application::TemplateHelper;

# Petal::Application::TemplateHelper is an object that is instantiated and added to a template to provide miscellaneous
# template operations such as url handlers and number formatting

use strict;
use warnings;

sub new {
	my ($self, $class, $app) = ({}, @_);

	bless $self, $class;
	$self->{app} = $app;
	return $self;
}

sub url {
	my ($self, @params) = @_;
	my $app = $self->{app};
	my $path = shift @params;
	
	my $url = $app->url($path);
	$url .= ($url =~ /\?/) ? '&' : '?';
	if(@params) {
		$url .= join '&', @params;
		$url .= '&';
	}
	return $url;
}

sub self {
	my ($self, $flag) = @_;
	my $url = $self->{app}->request->uri || '';
	$url .= ($url =~ /\?/) ? '&' : '?';
#	if($flag && $flag eq 'full') {
#		$url .= $self->{app}->request->args;
#	}
	$url .= ($url =~ /\?/) ? '&' : '?' unless $url =~ /\?$/;
	return $url;
}

sub home {
	my ($self, $append) = @_;
	$append ||= '';
	# base_url has an extra slash. get rid of it
	my $base_url = $self->{app}->base_url;
	return $base_url . $append;
}

sub printf {
	my ($self, $format, @params) = @_;
	return sprintf $format, @params;
}

sub dollar {
	my ($self, $amount) = @_;
	$amount ||= 0.00;
	return sprintf '$%.2f', $amount;
}


1;
